=== modified file 'bzrlib/tests/blackbox/test_diff.py'
--- bzrlib/tests/blackbox/test_diff.py	2006-07-05 05:03:34 +0000
+++ bzrlib/tests/blackbox/test_diff.py	2006-07-08 20:38:36 +0000
@@ -157,6 +157,26 @@
                               "+contents of branch1/file\n"
                               "\n", subst_dates(out))
 
+    def test_diff_revno_branches(self):
+        self.example_branches()
+        print >> open('branch2/file', 'wb'), 'even newer content'
+        self.run_bzr_captured(['commit', '-m', 'update file once more', 'branch2'])
+
+        out, err = self.run_bzr_captured(['diff', '-r', 'revno:1:branch2..revno:1:branch1'],
+                                         retcode=0)
+        self.assertEquals('', err)
+        self.assertEquals('', out)
+        out, ett = self.run_bzr_captured(['diff', '-r', 'revno:2:branch2..revno:1:branch1'],
+                                         retcode=1)
+        self.assertEquals('', err)
+        self.assertEqualDiff("=== modified file 'file'\n"
+                              "--- file\tYYYY-MM-DD HH:MM:SS +ZZZZ\n"
+                              "+++ file\tYYYY-MM-DD HH:MM:SS +ZZZZ\n"
+                              "@@ -1,1 +1,1 @@\n"
+                              "-new content\n"
+                              "+contents of branch1/file\n"
+                              "\n", subst_dates(out))
+
     def example_branch2(self):
         self.build_tree(['branch1/', 'branch1/file1'], line_endings='binary')
         self.capture('init branch1')

=== modified file 'bzrlib/tests/test_revisionnamespaces.py'
--- bzrlib/tests/test_revisionnamespaces.py	2006-05-24 00:06:33 +0000
+++ bzrlib/tests/test_revisionnamespaces.py	2006-07-08 20:38:36 +0000
@@ -27,6 +27,36 @@
 
 class TestRevisionNamespaces(TestCaseWithTransport):
 
+    def test_revno_n_path(self):
+        """Test revision specifiers.
+
+        These identify revisions by date, etc."""
+        wta = self.make_branch_and_tree('a')
+        ba = wta.branch
+        
+        wta.commit('Commit one', rev_id='a@r-0-1')
+        wta.commit('Commit two', rev_id='a@r-0-2')
+        wta.commit('Commit three', rev_id='a@r-0-3')
+
+        wtb = self.make_branch_and_tree('b')
+        bb = wtb.branch
+
+        wtb.commit('Commit one', rev_id='b@r-0-1')
+        wtb.commit('Commit two', rev_id='b@r-0-2')
+        wtb.commit('Commit three', rev_id='b@r-0-3')
+
+        self.assertEquals(RevisionSpec('revno:1:a/').in_history(ba),
+                          (1, 'a@r-0-1'))
+        # The argument of in_history should be ignored since it is
+        # redundant with the path in the spec.
+        self.assertEquals(RevisionSpec('revno:1:a/').in_history(None),
+                          (1, 'a@r-0-1'))
+        self.assertEquals(RevisionSpec('revno:1:a/').in_history(bb),
+                          (1, 'a@r-0-1'))
+        self.assertEquals(RevisionSpec('revno:2:b/').in_history(None),
+                          (2, 'b@r-0-2'))
+
+
     def test_revision_namespaces(self):
         """Test revision specifiers.
 

